package com.zayac.admin.system.model.req;

import java.io.Serial;
import java.time.LocalDateTime;

import cn.crane4j.annotation.AssembleMethod;
import cn.crane4j.annotation.ContainerMethod;
import cn.crane4j.annotation.Mapping;
import com.zayac.admin.common.enums.DisEnableStatusEnum;
import com.zayac.admin.system.enums.AccountTypeEnum;
import com.zayac.admin.system.model.resp.DeptResp;
import com.zayac.admin.system.model.resp.PlatformResp;
import com.zayac.admin.system.service.DeptService;
import com.zayac.admin.system.service.PlatformService;
import jakarta.validation.constraints.*;

import lombok.Data;

import io.swagger.v3.oas.annotations.media.Schema;

import org.hibernate.validator.constraints.Length;

import top.continew.starter.extension.crud.model.req.BaseReq;

/**
 * 创建或修改账号信息
 *
 * @author zayac
 * @since 2024/05/10 20:44
 */
@Data
@Schema(description = "创建或修改账号信息")
public class AccountReq extends BaseReq {

    @Serial
    private static final long serialVersionUID = 1L;

    /**
     * 账号昵称
     */
    @Schema(description = "账号昵称")
    @Length(max = 60, message = "账号昵称长度不能超过 {max} 个字符")
    private String nickname;

    /**
     * 账号
     */
    @Schema(description = "账号")
    @NotBlank(message = "账号不能为空")
    @Length(max = 20, message = "账号长度不能超过 {max} 个字符")
    private String username;

    /**
     * 密码
     */
    @Schema(description = "密码")
    @NotBlank(message = "密码不能为空")
    @Length(max = 64, message = "密码长度不能超过 {max} 个字符")
    private String password;

    /**
     * 账号类型(1:开云,2:华体会,3:九游,4:爱游戏)
     */
    @Schema(description = "账号类型(1:开云,2:华体会,3:九游,4:爱游戏)", type = "Integer", allowableValues = {"1", "2", "3", "4"}, example = "1")
    @NotNull(message = "账号类型不能为空")
    @AssembleMethod(targetType = PlatformService.class, method = @ContainerMethod(bindMethod = "getByPlatformId", resultType = PlatformResp.class), prop="id:platformId")
    private AccountTypeEnum type;

    /**
     * 状态（1：启用；2：禁用)
     */
    @Schema(description = "状态（1：启用；2：禁用）", type = "Integer", allowableValues = {"1", "2"}, example = "1")
    @NotNull(message = "状态（1：启用；2：禁用)不能为空")
    private DisEnableStatusEnum status;

    /**
     * 所属用户ID
     */
    @Schema(description = "所属用户", example = "123456789")
    private Long userId;

    /**
     * 所属平台ID
     */
    private Long platformId;

}